"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatImportStatements = void 0;
const config_1 = require("../config");
const categoriesOrder = ['thirdParty', 'userLibrary', 'differentModule', 'sameModule'];
function formatImportStatements(importCategories) {
    const { separator } = config_1.getConfig();
    const [first, ...otherCategories] = Object.entries(importCategories).filter(hasImports).sort(byCategoriesOrder).map(toImportBlock);
    let result = first || '';
    for (const imports of otherCategories) {
        result += `${separator}\n${imports}`;
    }
    return result;
}
exports.formatImportStatements = formatImportStatements;
function byCategoriesOrder([a], [b]) {
    return categoriesOrder.indexOf(a) - categoriesOrder.indexOf(b);
}
function hasImports([, imports]) {
    return imports.size > 0;
}
function toImportBlock([, imports]) {
    return [...imports.values()].map((l) => trim(l, ' \n')).join('\n');
}
function escapeRegex(string) {
    return string.replace(/[\[\](){}?*+\^$\\.|\-]/g, '\\$&');
}
function trim(input, characters) {
    characters = escapeRegex(characters);
    return input.replace(new RegExp('^[' + characters + ']+|[' + characters + ']+$', 'g'), '');
}
//# sourceMappingURL=format-import-statements.js.map